
# q-expansion of newform 3600.3.j.c, downloaded from the LMFDB on 17 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 3600
weight = 3
poly_data = [1, 0, -1, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, 0, 0, 1], 1], [[-1, 0, 2, 0], 1], [[0, 2, 0, -1], 1]]

hecke_ring_character_values = [[3151, [-1, 0, 0, 0]], [901, [1, 0, 0, 0]], [2801, [1, 0, 0, 0]], [577, [-1, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -3], [0, 0, 0, 0], [0, 23, 0, 0], [0, 0, 0, 0], [0, 0, -21, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 11, 0], [0, 26, 0, 0], [0, 0, 0, 0], [0, 0, 0, -13], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [-121, 0, 0, 0], [0, 0, 0, 77], [0, 0, 0, 0], [0, -46, 0, 0], [0, 0, 40, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, -167, 0, 0], [0, 0, 0, 0], [0, 0, 0, 40], [0, 0, 0, 0], [71, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 120], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, -160, 0], [0, 0, 0, 0], [0, 0, -171, 0], [0, -193, 0, 0], [0, 0, 0, -187], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [1, 0, 0, 0], [0, 0, 0, 0], [0, -143, 0, 0], [0, 0, 0, 0], [0, 0, -221, 0], [0, 0, 29, 0], [0, 0, 0, -253], [0, 0, 0, 0], [-409, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [-479, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, -280, 0], [0, -407, 0, 0], [0, 0, 0, 0], [0, 0, 0, 133], [0, 0, 0, 0], [0, 0, 0, 323], [0, 0, 0, 0], [0, 457, 0, 0], [0, 0, 0, 0], [0, 0, -320, 0], [0, -167, 0, 0], [0, 0, 0, 0], [502, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 403], [0, 577, 0, 0], [0, 0, -259, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, -793, 0, 0], [0, 0, 0, 0], [-769, 0, 0, 0], [0, 0, 0, 0], [358, 0, 0, 0], [0, 0, 0, 0], [0, -503, 0, 0], [0, 0, -299, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 814, 0, 0], [0, 0, 0, 0], [0, 0, 0, -440], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -437], [0, 0, 0, 0], [0, 0, -301, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -387], [241, 0, 0, 0], [0, 0, 0, 560], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, -651, 0], [0, -1033, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [1199, 0, 0, 0], [0, 0, 0, -520], [0, 1126, 0, 0], [0, 0, 0, 0], [0, 0, 459, 0], [0, 0, -29, 0], [0, 0, 0, 0], [0, 0, 0, 720], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [122, 0, 0, 0], [0, -1154, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 240, 0], [0, 0, 0, 0], [1391, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 637], [0, 1034, 0, 0], [0, 0, 480, 0], [0, 0, 0, 0], [0, 0, -520, 0], [0, 673, 0, 0], [0, 0, 0, 0], [-671, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -837], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 589, 0], [0, 0, 0, 0], [0, 0, 0, -893], [0, 0, 0, 0], [458, 0, 0, 0], [0, 0, 0, 0], [0, 1177, 0, 0], [0, 0, 0, 0], [0, 0, 560, 0], [0, 0, 0, 0], [0, 1727, 0, 0], [0, 0, 0, 0], [0, 0, 0, 987], [0, 0, 0, 0], [0, 0, 0, -1040], [0, 0, 0, 0], [0, 0, -901, 0], [0, 0, 0, 0], [0, 1847, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -680], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, -549, 0], [0, -1894, 0, 0], [-169, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [1679, 0, 0, 0], [0, 0, 0, 0], [0, 743, 0, 0], [0, 0, 259, 0], [0, 0, 0, 0], [0, 0, 1189, 0], [0, 0, 0, 0], [0, 0, 0, 1147], [1969, 0, 0, 0], [0, 0, 0, -1003], [0, 0, 0, 0], [0, -337, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 1873, 0, 0], [0, 0, 0, -67], [2231, 0, 0, 0], [0, 0, 0, 0], [0, -2257, 0, 0], [0, 0, 0, 0], [0, 0, -429, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [-2398, 0, 0, 0], [0, 74, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 680, 0], [0, -2426, 0, 0], [-2302, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 1419, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 451, 0], [0, 2447, 0, 0], [0, 0, 0, 0], [0, 0, 0, -533], [0, 0, 0, 0], [0, 0, 0, 0], [-2158, 0, 0, 0], [0, 0, 0, -1403], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [1801, 0, 0, 0], [0, 0, -301, 0], [0, 0, 0, 0], [0, 0, 0, 840], [0, 0, 0, 0], [2689, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -1517], [0, 0, 0, 0], [0, 1583, 0, 0], [0, 0, -1680, 0], [0, 0, 1189, 0], [0, 0, 0, 0], [0, 0, 0, -1520], [0, 0, 0, 0], [-1822, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, -1349, 0], [0, 0, 0, 693], [-2231, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -237], [0, 0, 0, 0], [0, 0, -1739, 0], [0, 0, 0, 0], [0, 694, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [2711, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [-2999, 0, 0, 0], [0, 0, 0, -480], [0, 0, 0, 0], [0, 1586, 0, 0], [0, 0, 0, -1533], [0, 0, 0, 0], [2138, 0, 0, 0], [0, 1177, 0, 0], [0, 0, 0, 0], [0, 0, 1920, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 1680], [0, 0, 0, 0], [-1081, 0, 0, 0], [0, 0, 0, -1120], [0, -3406, 0, 0], [0, 0, 581, 0], [0, -2687, 0, 0], [0, 0, 0, 747], [0, 0, 0, 0], [3049, 0, 0, 0], [-3601, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, -2040, 0], [0, 0, 0, 0], [-1321, 0, 0, 0], [0, 0, 0, 1363], [0, 0, 0, 0], [0, -3457, 0, 0], [0, 0, 0, 0], [0, 0, 200, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 3337, 0, 0], [0, 0, 0, 0], [0, 0, 51, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 1840], [0, -914, 0, 0], [0, 0, 0, 0], [0, 0, -1739, 0], [0, 0, 0, 0], [0, 0, 880, 0], [0, -3887, 0, 0], [0, 0, 0, 0], [1871, 0, 0, 0], [0, 0, 0, 0], [0, 4006, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, -1173], [0, 0, 0, 0], [-1369, 0, 0, 0], [0, 0, 0, 0], [0, 0, 0, 0], [0, 1703, 0, 0], [0, 0, 0, 0], [0, 0, -1600, 0], [0, -4153, 0, 0], [0, 0, 0, 0], [0, 0, 0, -1813], [0, 0, 0, 0], [478, 0, 0, 0]]
